stravalib.unithelper.UnitsQuantity
==================================

.. currentmodule:: stravalib.unithelper

.. autoclass:: UnitsQuantity


   .. automethod:: __init__


   .. rubric:: Methods

   .. autosummary::

      ~UnitsQuantity.__init__





   .. rubric:: Attributes

   .. autosummary::

      ~UnitsQuantity.num
      ~UnitsQuantity.unit
